@@ -1,4 +1,5 @@
 from http.server import BaseHTTPRequestHandler
+import logging
 
 
 class HealthCheckHandler(BaseHTTPRequestHandler):
@@ -7,3 +8,6 @@ class HealthCheckHandler(BaseHTTPRequestHandler):
         self.send_header("Cache-Control", "no-cache")
         self.end_headers()
         self.wfile.write(b"WORKING")
+
+    def log_message(self, format, *args):  # pylint: disable=redefined-builtin
+        logging.info(format.replace('\"', ""), *args)
