@@ -1,25 +1,30 @@
 from remotecv.result_store import BaseStore
-from remotecv.utils import logger, redis_client
+from remotecv.timing import get_time, get_interval
+from remotecv.utils import context, logger, redis_client
 
 
 class ResultStore(BaseStore):
-
-    WEEK = 604800
     redis_instance = None
 
     def __init__(self, config):
         super().__init__(config)
-
         if not ResultStore.redis_instance:
             ResultStore.redis_instance = redis_client()
+
+        self.redis_key_expire_time = config.redis_key_expire_time
         self.storage = ResultStore.redis_instance
 
     def store(self, key, points):
+        start_time = get_time()
         result = self.serialize(points)
         logger.debug("Points found: %s", result)
         redis_key = f"thumbor-detector-{key}"
-        self.storage.setex(
+        self.storage.set(
             name=redis_key,
             value=result,
-            time=2 * self.WEEK,
+            ex=self.redis_key_expire_time,
+        )
+        context.metrics.timing(
+            "worker.store_points.time",
+            get_interval(start_time, get_time()),
         )
