@@ -1,7 +1,8 @@
 from pyres import ResQ
 from pyres.worker import Worker
 
-from remotecv.utils import logger
+from remotecv.timing import get_time, get_interval
+from remotecv.utils import context, logger
 
 
 class UniqueQueue(ResQ):
@@ -16,13 +17,18 @@ class UniqueQueue(ResQ):
         if self.redis.get(unique_key) == b"1":
             # Do nothing as this message is already enqueued
             return False
-
         self.redis.set(unique_key, "1")
+
         return True
 
     def del_unique_key(self, queue, key):
+        start_time = get_time()
         unique_key = self._create_unique_key(queue, key)
         self.redis.delete(unique_key)
+        context.metrics.timing(
+            "worker.del_unique_key.time",
+            get_interval(start_time, get_time()),
+        )
 
     def enqueue_unique_from_string(
         self, klass_as_string, queue, args=None, key=None
@@ -69,3 +75,12 @@ class UniqueWorker(Worker):
             job._queue, job._payload["key"]  # pylint: disable=protected-access
         )
         return job
+
+    def reserve(self, timeout=10):
+        start_time = get_time()
+        job = super().reserve(timeout=timeout)
+        context.metrics.timing(
+            "worker.read_queue.time",
+            get_interval(start_time, get_time()),
+        )
+        return job
